@@ -12,14 +12,18 @@ User = get_user_model()
 class FirebaseAuthentication:
 
     def _get_auth_token(self, request):
-        encoded_token = request.META.get('HTTP_AUTHORIZATION').replace('jwt', '')
+        authorization = request.META.get('HTTP_AUTHORIZATION')
+        if authorization:
+            encoded_token = authorization.replace('jwt ', '')
+        else:
+            return None
         decoded_token = None
 
         try:
-            decoded_token = auth.verify_id_token(encoded_token, firebase_app, True)
+            decoded_token = auth.verify_id_token(encoded_token, firebase_app, False)
         except ValueError:
             pass
-        except auth.AuthError:
+        except Exception:
             pass
         return decoded_token
 
@@ -44,13 +48,16 @@ class FirebaseAuthentication:
             user = self._register_unregistered_user(firebase_uid)
             if hasattr(settings, 'REGISTER_FIREBASE_USER'):
                 try:
-                    register_user = importlib.import_module(settings.REGISTER_FIREBASE_USER)
+                    module = settings.REGISTER_FIREBASE_USER.split(".")
+
+                    m = importlib.import_module(".".join(module[0: -1]))
+                    register_user = getattr(m, module[-1])
                     register_user(user, decoded_token)
                 except Exception as e:
                     pass
         return user
 
-    def authenticate(self, request):
+    def authenticate(self, request, **kwargs):
         user = None
         decoded_token = self._get_auth_token(request)
 
